from polyscope_persistence.wrapper import PolyscopeObject, PolyscopeMesh, PolyscopePointcloud, PolyscopeVectorQuantity, \
    PolyscopeScalarQuantity, PolyscopeCurvenetwork
